summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--usr.bin/error/error.h6
-rw-r--r--usr.bin/error/pi.c6
-rw-r--r--usr.bin/error/subr.c7
3 files changed, 11 insertions, 8 deletions
diff --git a/usr.bin/error/pi.c b/usr.bin/error/pi.c
index be51abd296a..01cc7f5e2b1 100644
--- a/usr.bin/error/pi.c
+++ b/usr.bin/error/pi.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: pi.c,v 1.2 1996/06/26 05:32:45 deraadt Exp $ */
+/* $OpenBSD: pi.c,v 1.3 1998/11/16 06:22:28 deraadt Exp $ */
/* $NetBSD: pi.c,v 1.3 1995/09/02 06:15:44 jtc Exp $ */
/*
@@ -38,7 +38,7 @@
#if 0
static char sccsid[] = "@(#)pi.c 8.1 (Berkeley) 6/6/93";
#endif
-static char rcsid[] = "$OpenBSD: pi.c,v 1.2 1996/06/26 05:32:45 deraadt Exp $";
+static char rcsid[] = "$OpenBSD: pi.c,v 1.3 1998/11/16 06:22:28 deraadt Exp $";
#endif /* not lint */
#include <stdio.h>
@@ -234,7 +234,7 @@ Errorclass pi()
* Where the | is intended to be a down arrow, so that
* the pi error messages can be inserted above the
* line in error, instead of below. (All of the other
- * langauges put thier messages before the source line,
+ * language put thier messages before the source line,
* instead of after it as does pi.)
*
* where the pointer to the error has been truncated
diff --git a/usr.bin/error/subr.c b/usr.bin/error/subr.c
index 8969c1467b3..aa49356c6a8 100644
--- a/usr.bin/error/subr.c
+++ b/usr.bin/error/subr.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: subr.c,v 1.3 1997/06/17 20:56:40 kstailey Exp $ */
+/* $OpenBSD: subr.c,v 1.4 1998/11/16 06:22:28 deraadt Exp $ */
/* $NetBSD: subr.c,v 1.4 1995/09/10 15:55:15 christos Exp $ */
/*
@@ -38,7 +38,7 @@
#if 0
static char sccsid[] = "@(#)subr.c 8.1 (Berkeley) 6/6/93";
#endif
-static char rcsid[] = "$OpenBSD: subr.c,v 1.3 1997/06/17 20:56:40 kstailey Exp $";
+static char rcsid[] = "$OpenBSD: subr.c,v 1.4 1998/11/16 06:22:28 deraadt Exp $";
#endif /* not lint */
#include <stdio.h>
@@ -49,6 +49,7 @@ static char rcsid[] = "$OpenBSD: subr.c,v 1.3 1997/06/17 20:56:40 kstailey Exp $
/*
* Arrayify a list of rules
*/
+void
arrayify(e_length, e_array, header)
int *e_length;
Eptr **e_array;
@@ -75,6 +76,7 @@ arrayify(e_length, e_array, header)
}
/*VARARGS1*/
+void
error(msg, a1, a2, a3)
char *msg;
{
@@ -85,6 +87,7 @@ error(msg, a1, a2, a3)
fflush(stderr);
exit(6);
}
+
/*ARGSUSED*/
char *Calloc(nelements, size)
int nelements;
diff --git a/usr.bin/error/error.h b/usr.bin/error/error.h
index ee20262705a..6281704f9ff 100644
--- a/usr.bin/error/error.h
+++ b/usr.bin/error/error.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: error.h,v 1.3 1998/07/10 14:09:53 mickey Exp $ */
+/* $OpenBSD: error.h,v 1.4 1998/11/16 06:22:28 deraadt Exp $ */
/* $NetBSD: error.h,v 1.3 1995/09/02 06:15:25 jtc Exp $ */
/*
@@ -203,10 +203,10 @@ extern int nfiles;
extern Eptr **files; /* array of pointers into errors*/
boolean *touchedfiles; /* which files we touched */
/*
* The langauge the compilation is in, as intuited from
* the flavor of error messages analyzed.
*/
-extern int langauge;
+extern int language;
extern char *currentfilename;
/*
* Functional forwards
@@ -203,10 +203,10 @@ extern int nfiles;
boolean *touchedfiles; /* which files we touched */
/*
- * The langauge the compilation is in, as intuited from
+ * The language the compilation is in, as intuited from
* the flavor of error messages analyzed.
*/